Learn R Programming

pearson7 (version 1.0-3)

pearson7.fit: Find the MLE for a sample from the Pearson VII distribution with shape parameter 3/2.

Description

Find the MLE for a sample from the Pearson VII distribution with shape parameter 3/2.

Usage

pearson7.fit(y, mu0 = median(y), sigma0 = sqrt(3) * median(abs(y -
  median(y))), tol = 1e-08)

Arguments

y

a vector of observations.

mu0

an initial value for \(\mu\).

sigma0

an initial value for \(\sigma\).

tol

the convergence tolerance.

Value

pearson7.fit returns an object of class “pearson7”, which is a list containing the following components.

theta.hat

the estimates of \(\mu\) and \(\sigma\).

hessian

the Hessian matrix evaluated at theta.hat.

iterations

the number of iterations required to attain convergence.

value

the value of the log likelihood at theta.hat.

Details

This function uses a Newton-Raphson algorithm to find the MLE. The starting values for \(\mu\) and \(\sigma\) are the sample median and \(\sqrt{3}\) times the sample MAD, respectively. See the reference for details.

References

Hughes, J., Shastry, S., Hancock, W. O., and Fricks, J. (2013) Estimating velocity for processive motor proteins with random detachment. Journal of Agricultural, Biological, and Environmental Statistics, in press.

See Also

pearson7.objective

Examples

Run this code
# NOT RUN {
y = rpearson7(100, 100, 10)
fit = pearson7.fit(y)
fit
summary(fit)

# }

Run the code above in your browser using DataLab