pearson7.fit returns an object of class “pearson7”, which is a list containing the following components.
theta.hat
the estimates of \(\mu\) and \(\sigma\).
hessian
the Hessian matrix evaluated at theta.hat.
iterations
the number of iterations required to attain convergence.
value
the value of the log likelihood at theta.hat.
Details
This function uses a Newton-Raphson algorithm to find the MLE. The starting values for \(\mu\) and \(\sigma\) are the sample median and \(\sqrt{3}\) times the sample MAD, respectively. See the reference for details.
References
Hughes, J., Shastry, S., Hancock, W. O., and Fricks, J. (2013) Estimating velocity for processive motor proteins with random detachment. Journal of Agricultural, Biological, and Environmental Statistics, in press.